==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterDeprovisionStatusBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterDeprovisionStatusBuilder extends ClusterDeprovisionStatusFluentImpl<ClusterDeprovisionStatusBuilder> implements VisitableBuilder<ClusterDeprovisionStatus,ClusterDeprovisionStatusBuilder>{
  public ClusterDeprovisionStatusBuilder() {
    this(false);
  }
  public ClusterDeprovisionStatusBuilder(Boolean validationEnabled) {
    this(new ClusterDeprovisionStatus(), validationEnabled);
  }
  public ClusterDeprovisionStatusBuilder(ClusterDeprovisionStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterDeprovisionStatusBuilder(ClusterDeprovisionStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterDeprovisionStatus(), validationEnabled);
  }
  public ClusterDeprovisionStatusBuilder(ClusterDeprovisionStatusFluent<?> fluent,ClusterDeprovisionStatus instance) {
    this(fluent, instance, false);
  }
  public ClusterDeprovisionStatusBuilder(ClusterDeprovisionStatusFluent<?> fluent,ClusterDeprovisionStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withCompleted(instance.getCompleted());
      fluent.withConditions(instance.getConditions());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterDeprovisionStatusBuilder(ClusterDeprovisionStatus instance) {
    this(instance,false);
  }
  public ClusterDeprovisionStatusBuilder(ClusterDeprovisionStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withCompleted(instance.getCompleted());
      this.withConditions(instance.getConditions());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterDeprovisionStatusFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterDeprovisionStatus build() {
    ClusterDeprovisionStatus buildable = new ClusterDeprovisionStatus(fluent.getCompleted(),fluent.getConditions());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterDeprovisionStatusBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterDeprovisionStatusBuilder extends ClusterDeprovisionStatusFluent<ClusterDeprovisionStatusBuilder> implements VisitableBuilder<ClusterDeprovisionStatus,ClusterDeprovisionStatusBuilder>{
  public ClusterDeprovisionStatusBuilder() {
    this(false);
  }
  public ClusterDeprovisionStatusBuilder(Boolean validationEnabled) {
    this(new ClusterDeprovisionStatus(), validationEnabled);
  }
  public ClusterDeprovisionStatusBuilder(ClusterDeprovisionStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterDeprovisionStatusBuilder(ClusterDeprovisionStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterDeprovisionStatus(), validationEnabled);
  }
  public ClusterDeprovisionStatusBuilder(ClusterDeprovisionStatusFluent<?> fluent,ClusterDeprovisionStatus instance) {
    this(fluent, instance, false);
  }
  public ClusterDeprovisionStatusBuilder(ClusterDeprovisionStatusFluent<?> fluent,ClusterDeprovisionStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ClusterDeprovisionStatus());

    if (instance != null) {
      fluent.withCompleted(instance.getCompleted());
      fluent.withConditions(instance.getConditions());
      fluent.withCompleted(instance.getCompleted());
      fluent.withConditions(instance.getConditions());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterDeprovisionStatusBuilder(ClusterDeprovisionStatus instance) {
    this(instance,false);
  }
  public ClusterDeprovisionStatusBuilder(ClusterDeprovisionStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ClusterDeprovisionStatus());

    if (instance != null) {
      this.withCompleted(instance.getCompleted());
      this.withConditions(instance.getConditions());
      this.withCompleted(instance.getCompleted());
      this.withConditions(instance.getConditions());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterDeprovisionStatusFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterDeprovisionStatus build() {
    ClusterDeprovisionStatus buildable = new ClusterDeprovisionStatus(fluent.getCompleted(),fluent.buildConditions());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
